@@ -20,6 +20,7 @@ impl<'src> Node<'src> for Item<'src> {
     match self {
       Item::Alias(alias) => alias.tree(),
       Item::Assignment(assignment) => assignment.tree(),
+      Item::Comment(comment) => comment.tree(),
       Item::Recipe(recipe) => recipe.tree(),
       Item::Set(set) => set.tree(),
     }
@@ -210,3 +211,9 @@ impl<'src> Node<'src> for Warning {
     unreachable!()
   }
 }
+
+impl<'src> Node<'src> for str {
+  fn tree(&self) -> Tree<'src> {
+    Tree::atom("comment").push(["\"", self, "\""].concat())
+  }
+}
