@@ -14,6 +14,8 @@ mod error_messages;
 mod evaluate;
 mod examples;
 mod export;
+mod fmt;
+mod functions;
 mod init;
 mod interrupts;
 mod invocation_directory;
@@ -25,4 +27,5 @@ mod search;
 mod shebang;
 mod shell;
 mod string;
+mod sublime_syntax;
 mod working_directory;
